Types and the gRPC service for the v1 FunctionRunnerService API.
Modules
- credentials
- Nested message and enum types in
Credentials. - function_
runner_ service_ client - Generated client implementations.
- function_
runner_ service_ server - Generated server implementations.
- resource_
selector - Nested message and enum types in
ResourceSelector.
Structs
- Condition
- Status condition to be applied to the XR. Condition may also optionally be applied to the XR’s associated claim. For detailed information on proper usage of status conditions, please see https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#typical-status-properties.
- Credential
Data - CredentialData loaded by Crossplane, for example from a Secret.
- Credentials
- Credentials that a function may use to communicate with an external system.
- Match
Labels - MatchLabels defines a set of labels to match resources against.
- Request
Meta - RequestMeta contains metadata pertaining to a RunFunctionRequest.
- Requirements
- Requirements that must be satisfied for a function to run successfully.
- Resource
- A Resource represents the state of a Kubernetes resource.
- Resource
Selector - ResourceSelector selects a group of resources, either by name or by label.
- Resources
- Resources represents the state of several Crossplane resources.
- Response
Meta - ResponseMeta contains metadata pertaining to a RunFunctionResponse.
- Result
- A Result of running a function.
- RunFunction
Request - A RunFunctionRequest requests that the function be run.
- RunFunction
Response - A RunFunctionResponse contains the result of a function run.
- Schema
- Schema represents the OpenAPI schema for a resource kind.
- Schema
Selector - SchemaSelector identifies a resource kind whose OpenAPI schema is requested.
- State
- State of the XR (XR) and any resources.
Enums
- Capability
- Capability indicates that Crossplane supports a particular feature. Functions can check for capabilities to determine whether Crossplane will honor a particular request or response field.
- Ready
- Ready indicates whether a resource should be considered ready.
- Severity
- Severity of function results.
- Status
- Target
- Target of function results and conditions.