#[repr(i32)]pub enum Capability {
Unspecified = 0,
Capabilities = 1,
RequiredResources = 2,
Credentials = 3,
Conditions = 4,
RequiredSchemas = 5,
}Expand description
Capability indicates that Crossplane supports a particular feature. Functions can check for capabilities to determine whether Crossplane will honor a particular request or response field.
Variants
Unspecified = 0
Capabilities = 1
Crossplane sends capabilities in RequestMeta. If this capability is present, the function knows that if another capability is absent, it’s because Crossplane doesn’t support it (not because Crossplane predates capability advertisement). Added in Crossplane v2.2.
RequiredResources = 2
Crossplane supports the requirements.resources field. Functions can return resource requirements and Crossplane will fetch the requested resources and return them in required_resources. Added in Crossplane v1.15.
Credentials = 3
Crossplane supports the credentials field. Functions can receive credentials from secrets specified in the Composition. Added in Crossplane v1.16.
Conditions = 4
Crossplane supports the conditions field. Functions can return status conditions to be applied to the XR and optionally its claim. Added in Crossplane v1.17.
RequiredSchemas = 5
Crossplane supports the requirements.schemas field. Functions can request OpenAPI schemas and Crossplane will return them in required_schemas. Added in Crossplane v2.2.
Implementations
Sourceimpl Capability
impl Capability
Sourceimpl Capability
impl Capability
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.