#[repr(i32)]pub enum Ready {
Unspecified = 0,
True = 1,
False = 2,
}Expand description
Ready indicates whether a resource should be considered ready.
Variants
Unspecified = 0
True = 1
True means the resource has been observed to be ready.
False = 2
False means the resource has not been observed to be ready.
Implementations
Sourceimpl Ready
impl Ready
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.