#[repr(i32)]pub enum Severity {
Unspecified = 0,
Fatal = 1,
Warning = 2,
Normal = 3,
}Expand description
Severity of function results.
Variants
Unspecified = 0
Fatal = 1
Fatal results are fatal; subsequent functions may run, but the function pipeline run will be considered a failure and the first fatal result will be returned as an error.
Warning = 2
Warning results are non-fatal; the entire pipeline will run to completion but warning events and debug logs associated with the XR or Operation will be emitted.
Normal = 3
Normal results are emitted as normal events and debug logs associated with the XR or operation.
Implementations
Sourceimpl Severity
impl Severity
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.