Target

Enum Target 

#[repr(i32)]
pub enum Target { Unspecified = 0, Composite = 1, CompositeAndClaim = 2, }
Target of function results and conditions.

Variants



Unspecified = 0

If the target is unspecified, the result targets the XR.



Composite = 1

Target the XR. Results that target the XR should include detailed, advanced information.



CompositeAndClaim = 2

Target the XR and the claim. Results that target the XR and the claim should include only end-user friendly information.

Implementations

Source

impl Target

pub const fn is_valid(value: i32) -> bool

Returns true if value is a variant of Target.

pub fn from_i32(value: i32) -> Option<Target>

👎Deprecated:

Use the TryFrom<i32> implementation instead

Converts an i32 to a Target, or None if value is not a valid variant.

Source

impl Target

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.