pub struct Condition {
pub type: String,
pub status: i32,
pub reason: String,
pub message: Option<String>,
pub target: Option<i32>,
}Expand description
Status condition to be applied to the XR. Condition may also optionally be applied to the XR’s associated claim. For detailed information on proper usage of status conditions, please see https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#typical-status-properties.
Fields
type: StringType of condition in PascalCase.
status: i32Status of the condition.
reason: StringReason contains a programmatic identifier indicating the reason for the condition’s last transition. Producers of specific condition types may define expected values and meanings for this field, and whether the values are considered a guaranteed API. The value should be a PascalCase string. This field may not be empty.
message: Option<String>Message is a human readable message indicating details about the transition. This may be an empty string.
target: Option<i32>The resources this condition targets.
Implementations
Sourceimpl Condition
impl Condition
Sourcepub fn status(&self) -> Status
pub fn status(&self) -> Status
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: Status)
pub fn set_status(&mut self, value: Status)
Sets status to the provided enum value.
Sourcepub fn message(&self) -> &str
pub fn message(&self) -> &str
Returns the value of message, or the default value if message is unset.
Sourcepub fn target(&self) -> Target
pub fn target(&self) -> Target
Returns the enum value of target, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_target(&mut self, value: Target)
pub fn set_target(&mut self, value: Target)
Sets target to the provided enum value.