pub struct RequestMeta {
pub tag: String,
pub capabilities: Vec<i32>,
}Expand description
RequestMeta contains metadata pertaining to a RunFunctionRequest.
Fields
tag: StringAn opaque string identifying a request. Requests with identical tags will be otherwise identical.
capabilities: Vec<i32>Capabilities supported by this version of Crossplane. Functions may use this to determine whether Crossplane will honor certain fields in their response, or populate certain fields in their request.
Implementations
Sourceimpl RequestMeta
impl RequestMeta
Sourcepub fn capabilities(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<Capability>> ⓘ
pub fn capabilities( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<Capability>> ⓘ
Returns an iterator which yields the valid enum values contained in capabilities.
Sourcepub fn push_capabilities(&mut self, value: Capability)
pub fn push_capabilities(&mut self, value: Capability)
Appends the provided enum value to capabilities.