pub struct Requirements {
pub extra_resources: HashMap<String, ResourceSelector>,
pub resources: HashMap<String, ResourceSelector>,
pub schemas: HashMap<String, SchemaSelector>,
}Expand description
Requirements that must be satisfied for a function to run successfully.
Fields
extra_resources: HashMap<String, ResourceSelector>Resources that this function requires. The map key uniquely identifies the group of resources.
Deprecated: Use resources instead.
resources: HashMap<String, ResourceSelector>Resources that this function requires. The map key uniquely identifies the group of resources.
schemas: HashMap<String, SchemaSelector>Schemas that this function requires. The map key uniquely identifies the schema request.