pub struct ResourceSelector {
pub api_version: String,
pub kind: String,
pub namespace: Option<String>,
pub match: Option<Match>,
}Expand description
ResourceSelector selects a group of resources, either by name or by label.
Fields
api_version: StringAPI version of resources to select.
kind: StringKind of resources to select.
namespace: Option<String>Match resources in this namespace. Omit namespace to match cluster scoped resources, or to match namespaced resources by labels across all namespaces.
match: Option<Match>Resources to match.
Implementations