pub struct ResponseMeta {
pub tag: String,
pub ttl: Option<Duration>,
}Expand description
ResponseMeta contains metadata pertaining to a RunFunctionResponse.
Fields
tag: StringAn opaque string identifying the content of the request. Must match the meta.tag of the corresponding RunFunctionRequest.
ttl: Option<Duration>Time-to-live of this response. Crossplane will call the function again when the TTL expires. Crossplane may cache the response to avoid calling the function again until the TTL expires.