pub struct Result {
pub severity: i32,
pub message: String,
pub reason: Option<String>,
pub target: Option<i32>,
}Expand description
A Result of running a function.
Fields
severity: i32Severity of this result.
message: StringHuman-readable details about the result.
reason: Option<String>Optional PascalCase, machine-readable reason for this result. If omitted, the value will be ComposeResources.
target: Option<i32>The resources this result targets.
Implementations
Sourceimpl Result
impl Result
Sourcepub fn severity(&self) -> Severity
pub fn severity(&self) -> Severity
Returns the enum value of severity, or the default if the field is set to an invalid enum value.
Sourcepub fn set_severity(&mut self, value: Severity)
pub fn set_severity(&mut self, value: Severity)
Sets severity to the provided enum value.
Sourcepub fn reason(&self) -> &str
pub fn reason(&self) -> &str
Returns the value of reason, or the default value if reason is unset.
Sourcepub fn target(&self) -> Target
pub fn target(&self) -> Target
Returns the enum value of target, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_target(&mut self, value: Target)
pub fn set_target(&mut self, value: Target)
Sets target to the provided enum value.