pub struct RunFunctionRequest {
pub meta: Option<RequestMeta>,
pub observed: Option<State>,
pub desired: Option<State>,
pub input: Option<Struct>,
pub context: Option<Struct>,
pub extra_resources: HashMap<String, Resources>,
pub credentials: HashMap<String, Credentials>,
pub required_resources: HashMap<String, Resources>,
pub required_schemas: HashMap<String, Schema>,
}Expand description
A RunFunctionRequest requests that the function be run.
Fields
meta: Option<RequestMeta>Metadata pertaining to this request.
observed: Option<State>The observed state prior to invocation of a function pipeline. State passed to each function is fresh as of the time the pipeline was invoked, not as of the time each function was invoked.
desired: Option<State>Desired state according to a function pipeline. The state passed to a particular function may have been accumulated by previous functions in the pipeline.
Note that the desired state must be a partial object with only the fields that this function (and its predecessors in the pipeline) wants to have set in the object. Copying a non-partial observed state to desired is most likely not what you want to do. Leaving out fields that had been returned as desired before will result in them being deleted from the objects in the cluster.
input: Option<Struct>Optional input specific to this function invocation. A JSON representation of the ‘input’ block of the relevant entry in a function pipeline.
context: Option<Struct>Optional context. Crossplane may pass arbitrary contextual information to a function. A function may also return context in its RunFunctionResponse, and that context will be passed to subsequent functions. Crossplane discards all context returned by the last function in the pipeline.
extra_resources: HashMap<String, Resources>Optional resources that the function specified in its requirements. Note that resources is a map to Resources, plural. The map key corresponds to the key in a RunFunctionResponse’s requirements.extra_resources field. If a function requested extra resources that did not exist, Crossplane sets the map key to an empty Resources message to indicate that it attempted to satisfy the request. This field is only populated when the function uses extra_resources in its requirements.
Deprecated: Use required_resources instead.
credentials: HashMap<String, Credentials>Optional credentials that this function may use to communicate with an external system.
required_resources: HashMap<String, Resources>Optional resources that the function specified in its requirements. Note that resources is a map to Resources, plural. The map key corresponds to the key in a RunFunctionResponse’s requirements.resources field. If a function requested required resources that did not exist, Crossplane sets the map key to an empty Resources message to indicate that it attempted to satisfy the request. This field is only populated when the function uses resources in its requirements.
required_schemas: HashMap<String, Schema>Optional schemas that the function specified in its requirements. The map key corresponds to the key in a RunFunctionResponse’s requirements.schemas field. If a function requested a schema that could not be found, Crossplane sets the map key to an empty Schema message to indicate that it attempted to satisfy the request.