pub fn get_context_key(req: &RunFunctionRequest, key: &str) -> Option<Value>Expand description
Gets a function context value by key, if present.
See crate::context for well-known context keys.
pub fn get_context_key(req: &RunFunctionRequest, key: &str) -> Option<Value>Gets a function context value by key, if present.
See crate::context for well-known context keys.