pub fn get_credential_data<'a>(
req: &'a RunFunctionRequest,
name: &str,
) -> Option<&'a CredentialData>Expand description
Gets the supplied credential data from the request, if any.
pub fn get_credential_data<'a>(
req: &'a RunFunctionRequest,
name: &str,
) -> Option<&'a CredentialData>Gets the supplied credential data from the request, if any.