get_required_resources

Function get_required_resources 

pub fn get_required_resources(
    req: &RunFunctionRequest,
    name: &str,
) -> Option<Vec<Value>>
Gets required resources by requirement name from the request.

Returns None when Crossplane has not (yet) resolved the requirement, and an empty Vec when it resolved the requirement but found no matches. Always declare requirements with crate::response::require_resources; Crossplane considers them satisfied when they stabilize across calls.