get_watched_resource

Function get_watched_resource 

pub fn get_watched_resource(req: &RunFunctionRequest) -> Option<Value>
Gets the watched resource that triggered this operation, if any.

When a WatchOperation creates an Operation it injects the resource that changed under the requirement name WATCHED_RESOURCE_KEY.