set_ready

Function set_ready 

pub fn set_ready(r: &mut Resource, ready: Ready)
Sets whether a desired resource should be considered ready.

Set Ready::True on a desired composed resource to mark it ready, or on the desired XR to override Crossplane’s standard readiness detection.