Module response

Module response 

Helpers for working with RunFunctionResponses.

Enums

ResourceMatch
How a resource requirement matches resources.

Constants

DEFAULT_TTL
The default TTL for which a RunFunctionResponse may be cached.

Functions

condition_false
Adds a False status condition to be applied to the XR.
condition_true
Adds a True status condition to be applied to the XR.
condition_unknown
Adds an Unknown status condition to be applied to the XR.
fatal
Adds a fatal result to the response.
normal
Adds a normal result to the response.
require_resources
Adds a resource requirement to the response.
require_schema
Adds a schema requirement to the response.
set_context_key
Sets a function context value by key.
set_output
Sets the output of an operation function.
to
Creates a response to the supplied request.
warning
Adds a warning result to the response.