condition_true

Function condition_true 

pub fn condition_true(
    rsp: &mut RunFunctionResponse,
    typ: impl Into<String>,
    reason: impl Into<String>,
) -> &mut Condition
Adds a True status condition to be applied to the XR.

Returns the added condition so a message or target can be set on it. Do not set the Ready condition type; Crossplane manages it from resource readiness.