fatal

Function fatal 

pub fn fatal(
    rsp: &mut RunFunctionResponse,
    message: impl Into<String>,
) -> &mut Result
Adds a fatal result to the response.

The pipeline run is considered a failure and the first fatal result is returned as an error, but subsequent pipeline steps may still run.