to

Function to 

pub fn to(req: &RunFunctionRequest, ttl: Duration) -> RunFunctionResponse
Creates a response to the supplied request.

The request’s tag, desired state, and context are copied to the response. Crossplane deletes any previously desired field or resource that is not copied forward, so always start from this function rather than from an empty response.