#[repr(i32)]pub enum Target {
Unspecified = 0,
Composite = 1,
CompositeAndClaim = 2,
}Expand description
Target of function results and conditions.
Variants
Unspecified = 0
If the target is unspecified, the result targets the XR.
Composite = 1
Target the XR. Results that target the XR should include detailed, advanced information.
CompositeAndClaim = 2
Target the XR and the claim. Results that target the XR and the claim should include only end-user friendly information.
Implementations
Sourceimpl Target
impl Target
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.