pub struct Resource {
pub resource: Option<Struct>,
pub connection_details: HashMap<String, Vec<u8>>,
pub ready: i32,
}Expand description
A Resource represents the state of a Kubernetes resource.
Fields
resource: Option<Struct>The JSON representation of the resource.
-
Crossplane will set this field in a RunFunctionRequest to the entire observed state of a resource - including its metadata, spec, and status.
-
A function should set this field in a RunFunctionRequest to communicate the desired state of the resource.
-
A function may only specify the desired status of a XR - not its metadata or spec. A function should not return desired metadata or spec for a XR. This will be ignored.
-
A function may not specify the desired status of any other resource - e.g. composed resources. It may only specify their metadata and spec. Status will be ignored.
connection_details: HashMap<String, Vec<u8>>The resource’s connection details.
-
Crossplane will set this field in a RunFunctionRequest to communicate the the observed connection details of a composite or composed resource.
-
A function should set this field in a RunFunctionResponse to indicate the desired connection details of legacy XRs. For modern XRs, this will be ignored.
-
A function should not set this field in a RunFunctionResponse to indicate the desired connection details of a composed resource. This will be ignored.
Connection details are only used for composition. They’re ignored by Operations.
ready: i32Ready indicates whether the resource should be considered ready.
-
Crossplane will never set this field in a RunFunctionRequest.
-
A function should set this field to READY_TRUE in a RunFunctionResponse to indicate that a desired resource is ready.
-
A function should set this field to READY_TRUE in a RunFunctionResponse to indicate that a desired XR is ready. This overwrites the standard readiness detection that determines the ready state of the composite by the ready state of the composed resources.
Ready is only used for composition. It’s ignored by Operations.
Implementations