pub struct RunFunctionResponse {
pub meta: Option<ResponseMeta>,
pub desired: Option<State>,
pub results: Vec<Result>,
pub context: Option<Struct>,
pub requirements: Option<Requirements>,
pub conditions: Vec<Condition>,
pub output: Option<Struct>,
}Expand description
A RunFunctionResponse contains the result of a function run.
Fields
meta: Option<ResponseMeta>Metadata pertaining to this response.
desired: Option<State>Desired state according to a function pipeline. functions may add desired state, and may mutate or delete any part of the desired state they are concerned with. A function must pass through any part of the desired state that it is not concerned with.
Note that the desired state must be a partial object with only the fields that this function (and its predecessors in the pipeline) wants to have set in the object. Copying a non-partial observed state to desired is most likely not what you want to do. Leaving out fields that had been returned as desired before will result in them being deleted from the objects in the cluster.
results: Vec<Result>Results of the function run. Results are used for observability purposes.
context: Option<Struct>Optional context to be passed to the next function in the pipeline as part of the RunFunctionRequest. Dropped on the last function in the pipeline.
requirements: Option<Requirements>Requirements that must be satisfied for this function to run successfully.
conditions: Vec<Condition>Status conditions to be applied to the XR. Conditions may also optionally be applied to the XR’s associated claim.
Conditions are only used for composition. They’re ignored by Operations.
output: Option<Struct>Optional output specific to this function invocation.
Only Operations use function output. XRs will discard any function output.