Module resource

Module resource 

Helpers for working with composite and composed resources.

Structs

Condition
A status condition of a resource.

Functions

add_connection_detail
Adds a connection detail to a resource.
child_name
Builds a deterministic, DNS-label-safe name for a child resource.
get_condition
Gets the supplied status condition of the supplied resource.
json_to_pb
Converts a JSON value to a protobuf Value. Numbers become f64.
json_to_struct
Converts a JSON object to a protobuf Struct.
pb_to_json
Converts a protobuf Value to a JSON value. NaN and infinity become null.
set_ready
Sets whether a desired resource should be considered ready.
struct_to_json
Converts a protobuf Struct to a JSON value.
update
Updates a composite or composed resource from any serializable source.
update_status
Updates a resource’s status from any serializable source.