Helpers for working with RunFunctionResponses.
Enums
- Resource
Match - How a resource requirement matches resources.
Constants
- DEFAULT_
TTL - The default TTL for which a RunFunctionResponse may be cached.
Functions
- condition_
false - Adds a False status condition to be applied to the XR.
- condition_
true - Adds a True status condition to be applied to the XR.
- condition_
unknown - Adds an Unknown status condition to be applied to the XR.
- fatal
- Adds a fatal result to the response.
- normal
- Adds a normal result to the response.
- require_
resources - Adds a resource requirement to the response.
- require_
schema - Adds a schema requirement to the response.
- set_
context_ key - Sets a function context value by key.
- set_
output - Sets the output of an operation function.
- to
- Creates a response to the supplied request.
- warning
- Adds a warning result to the response.