pub fn require_resources(
rsp: &mut RunFunctionResponse,
name: impl Into<String>,
api_version: impl Into<String>,
kind: impl Into<String>,
match: Option<ResourceMatch>,
namespace: Option<String>,
)Expand description
Adds a resource requirement to the response.
Crossplane fetches the matching resources and calls the function again
with them in req.required_resources[name]. Matching None selects all
resources of the given API version and kind. Omit the namespace to match
cluster scoped resources, or to match namespaced resources by labels
across all namespaces.